@@ -1,5 +1,5 @@
 #!/usr/bin/env bash
-# Copyright (C) 2017 The Qt Company Ltd.
+# Copyright (C) 2025 The Qt Company Ltd.
 # SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 # Install required packages with APT
@@ -20,14 +20,19 @@ function set_internal_repo {
     sudo mv /etc/apt/apt.conf.d/50appstream{,.disabled}
 
     sudo tee "/etc/apt/sources.list" > /dev/null <<-EOC
-    deb [arch=amd64] http://repo-clones.ci.qt.io/apt-mirror/mirror/ubuntu/ bionic main restricted universe multiverse
-    deb [arch=amd64] http://repo-clones.ci.qt.io/apt-mirror/mirror/ubuntu/ bionic-updates main restricted universe multiverse
-    deb [arch=amd64] http://repo-clones.ci.qt.io/apt-mirror/mirror/ubuntu/ bionic-backports main restricted universe
-    deb [arch=amd64] http://repo-clones.ci.qt.io/apt-mirror/mirror/ubuntu/ bionic-security main restricted universe multiverse
+    deb [arch=amd64 trusted=yes] http://repo-clones-apt.ci.qt.io:8080 focal-amd64 main restricted universe multiverse
+    deb [arch=amd64 trusted=yes] http://repo-clones-apt.ci.qt.io:8080 focal-updates-amd64 main restricted universe multiverse
+    deb [arch=amd64 trusted=yes] http://repo-clones-apt.ci.qt.io:8080 focal-backports-amd64 main restricted universe
+    deb [arch=amd64 trusted=yes] http://repo-clones-apt.ci.qt.io:8080 focal-security-amd64 main restricted universe multiverse
+    deb [arch=i386 trusted=yes] http://repo-clones-apt.ci.qt.io:8080 focal-i386 main restricted universe
+    deb [arch=i386 trusted=yes] http://repo-clones-apt.ci.qt.io:8080 focal-updates-i386 main restricted
 EOC
 }
 
-(ping -c 3 repo-clones.ci.qt.io && set_internal_repo) || echo "Internal package repository not found. Using public repositories."
+(ping -c 3 repo-clones-apt.ci.qt.io && set_internal_repo) || echo "Internal package repository not found. Using public repositories."
+
+# Make sure needed ca-certificates are available
+sudo apt-get install --reinstall ca-certificates
 
 # Git is not needed by builds themselves, but is nice to have
 # immediately as one starts debugging
@@ -50,11 +55,21 @@ installPackages+=(libxi-dev)
 installPackages+=(libdbus-1-dev)
 # Needed libraries for WebEngine
 installPackages+=(libudev-dev)
+installPackages+=(libdrm-dev)
 installPackages+=(libegl1-mesa-dev)
 installPackages+=(libfontconfig1-dev)
+installPackages+=(libgbm-dev)
+installPackages+=(liblcms2-dev)
+installPackages+=(libpci-dev)
+installPackages+=(libre2-dev)
+installPackages+=(libsnappy-dev)
+installPackages+=(libva-dev)
+installPackages+=(libvpx-dev)
+installPackages+=(libxkbfile-dev)
+installPackages+=(libxshmfence-dev)
 installPackages+=(libxss-dev)
-installPackages+=(nodejs)
-# NOTE! Can't install nodejs-dev because libssl1.0-dev conflicts with libssl1.0-dev which is depandency of nodejs-dev.
+installPackages+=(nodejs-mozilla) # use nodejs-mozilla because nodejs is outdated
+installPackages+=(python3-html5lib)
 
 # Common event loop handling
 installPackages+=(libglib2.0-dev)
@@ -86,6 +101,9 @@ installPackages+=(gstreamer1.0-plugins-good)
 installPackages+=(gstreamer1.0-plugins-bad)
 installPackages+=(gstreamer1.0-plugins-rtp)
 installPackages+=(gstreamer1.0-plugins-ugly)
+installPackages+=(libgstreamer-gl1.0-0)
+installPackages+=(gir1.2-gst-plugins-base-1.0)
+installPackages+=(gir1.2-gst-plugins-bad-1.0)
 installPackages+=(yasm)
 installPackages+=(libva-dev)
 # for QtMultimedia streaming tests
@@ -108,12 +126,19 @@ installPackages+=(mesa-common-dev)
 installPackages+=(libgl1-mesa-glx)
 installPackages+=(libgl1-mesa-dev)
 installPackages+=(libegl1-mesa-dev)
+installPackages+=(libegl1)
+installPackages+=(libegl-mesa0)
+installPackages+=(libegl-dev)
+installPackages+=(libglvnd-dev)
+installPackages+=(libgles2-mesa-dev)
 installPackages+=(curl)
 installPackages+=(libcurl4-openssl-dev)
 installPackages+=(libicu-dev)
 installPackages+=(zlib1g-dev)
 installPackages+=(zlib1g)
 installPackages+=(openjdk-8-jdk)
+#Java 17 for Android
+installPackages+=(openjdk-17-jdk)
 installPackages+=(libgtk-3-dev)
 installPackages+=(ninja-build)
 installPackages+=(libssl-dev)
@@ -122,8 +147,7 @@ installPackages+=(libxcomposite-dev)
 installPackages+=(libxdamage-dev)
 installPackages+=(libxrandr-dev)
 installPackages+=(libfontconfig1-dev)
-installPackages+=(libxss-dev)
-installPackages+=(libsrtp0-dev)
+installPackages+=(libsrtp2-dev)
 installPackages+=(libwebp-dev)
 installPackages+=(libjsoncpp-dev)
 installPackages+=(libopus-dev)
@@ -168,6 +192,31 @@ installPackages+=(ruby)
 installPackages+=(libxslt1-dev)
 installPackages+=(libxml2-dev)
 installPackages+=(libhyphen-dev)
+# For remote access
+installPackages+=(ssh)
+# For bitbake
+installPackages+=(diffstat)
+installPackages+=(binfmt-support)
+installPackages+=(zstd)
+installPackages+=(libzstd-dev)
+# Vulkan is needed for examples
+installPackages+=(libvulkan-dev)
+# Needed for qtdltlogging
+installPackages+=(libdlt-dev)
+# For integrity
+installPackages+=(libc6:i386)
+installPackages+=(libncurses5:i386)
+installPackages+=(libstdc++6:i386)
+installPackages+=(libx11-6:i386)
+installPackages+=(lib32z1)
+installPackages+=(linux-libc-dev:i386)
+installPackages+=(libxcursor1:i386)
+installPackages+=(libc6-dev-i386)
+sudo dpkg --add-architecture i386
+# For QNX
+installPackages+=(nfs-kernel-server)
+installPackages+=(net-tools)
+installPackages+=(bridge-utils)
 # Fix dependencies in shared ffmpeg libs
 installPackages+=(patchelf)
 
@@ -182,5 +231,8 @@ sudo DEBIAN_FRONTEND=noninteractive apt-get -q -y install "${installPackages[@]}
 pip config --user set global.index https://ci-files01-hki.ci.qt.io/input/python_module_cache
 pip config --user set global.extra-index-url https://pypi.org/simple/
 
+source "${BASH_SOURCE%/*}/../common/unix/SetEnvVar.sh"
+SetEnvVar "PATH" "/usr/lib/nodejs-mozilla/bin:\$PATH"
+
 OpenSSLVersion="$(openssl version |cut -b 9-14)"
 echo "OpenSSL = $OpenSSLVersion" >> ~/versions.txt
